'use strict';

const MagicString = require('magic-string');
const core = require('@unocss/core');
const config = require('@unocss/config');
const vite = require('@unocss/vite');
const presetUno = require('@unocss/preset-uno');
const transformerDirectives = require('@unocss/transformer-directives');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

const MagicString__default = /*#__PURE__*/_interopDefaultLegacy(MagicString);
const presetUno__default = /*#__PURE__*/_interopDefaultLegacy(presetUno);

function SveltePreprocessUnocss(configOrPath, defaults = {
  presets: [
    presetUno__default()
  ]
}) {
  let uno;
  return {
    markup: async ({ content, filename }) => {
      if (!uno)
        uno = await init(configOrPath, defaults);
      let code = content;
      const result = await vite.transformSvelteSFC(code, filename || "", uno);
      if (result?.code)
        code = result.code;
      if (result?.map) {
        return {
          code,
          map: result.map
        };
      } else {
        return {
          code
        };
      }
    },
    style: async ({ content }) => {
      if (!uno)
        uno = await init(configOrPath, defaults);
      const s = new MagicString__default(content);
      await transformerDirectives.transformDirectives(s, uno, {
        varStyle: "--at-"
      });
      if (s.hasChanged())
        return { code: s.toString() };
    }
  };
}
async function init(configOrPath, defaults) {
  const { config: config$1 } = await config.loadConfig(process.cwd(), configOrPath);
  return core.createGenerator(config$1, defaults);
}

module.exports = SveltePreprocessUnocss;
