import MagicString from 'magic-string';
import { createGenerator } from '@unocss/core';
import { loadConfig } from '@unocss/config';
import { transformSvelteSFC } from '@unocss/vite';
import presetUno from '@unocss/preset-uno';
import { transformDirectives } from '@unocss/transformer-directives';

function SveltePreprocessUnocss(configOrPath, defaults = {
  presets: [
    presetUno()
  ]
}) {
  let uno;
  return {
    markup: async ({ content, filename }) => {
      if (!uno)
        uno = await init(configOrPath, defaults);
      let code = content;
      const result = await transformSvelteSFC(code, filename || "", uno);
      if (result?.code)
        code = result.code;
      if (result?.map) {
        return {
          code,
          map: result.map
        };
      } else {
        return {
          code
        };
      }
    },
    style: async ({ content }) => {
      if (!uno)
        uno = await init(configOrPath, defaults);
      const s = new MagicString(content);
      await transformDirectives(s, uno, {
        varStyle: "--at-"
      });
      if (s.hasChanged())
        return { code: s.toString() };
    }
  };
}
async function init(configOrPath, defaults) {
  const { config } = await loadConfig(process.cwd(), configOrPath);
  return createGenerator(config, defaults);
}

export { SveltePreprocessUnocss as default };
